@@ -18,7 +18,7 @@ def vector_module(vector):
     return mt.sqrt(sum_comp)
 
 
-def isequivalent2d(lista_vetores):
+def equivalent2d(lista_vetores):
     comp_x_eq = None
     comp_y_eq = None
 
@@ -48,7 +48,7 @@ def isequivalent2d(lista_vetores):
         return True
 
 
-def isequivalent3d(lista_vetores):
+def equivalent3d(lista_vetores):
     comp_x_eq = None
     comp_y_eq = None
     comp_z_eq = None
@@ -131,3 +131,7 @@ def plot3d(lista_vetores,lista_cores,lista_limites):
                       length=1, normalize=False, color=lista_cores[i])
 
     plt.show()
+
+x=(0,0,2,2)
+w=(-1,-1,1,1)
+print(isequivalent2d([x,w]))
\ No newline at end of file
